aboutsummaryrefslogtreecommitdiff
path: root/yarn/src/main
diff options
context:
space:
mode:
authorjerryshao <sshao@hortonworks.com>2016-02-23 12:30:57 +0000
committerSean Owen <sowen@cloudera.com>2016-02-23 12:30:57 +0000
commite99d0170982b06676110906db4de6196586829f6 (patch)
treebcd00ef6354908f8b02aa99b1eaeae5252e7a026 /yarn/src/main
parent87250580f214cb7c4dff01c5a3498ea6cb79a27e (diff)
downloadspark-e99d0170982b06676110906db4de6196586829f6.tar.gz
spark-e99d0170982b06676110906db4de6196586829f6.tar.bz2
spark-e99d0170982b06676110906db4de6196586829f6.zip
[SPARK-13220][CORE] deprecate yarn-client and yarn-cluster mode
Author: jerryshao <sshao@hortonworks.com> Closes #11229 from jerryshao/SPARK-13220.
Diffstat (limited to 'yarn/src/main')
-rw-r--r--yarn/src/main/scala/org/apache/spark/deploy/yarn/ApplicationMaster.scala5
1 files changed, 3 insertions, 2 deletions
diff --git a/yarn/src/main/scala/org/apache/spark/deploy/yarn/ApplicationMaster.scala b/yarn/src/main/scala/org/apache/spark/deploy/yarn/ApplicationMaster.scala
index cccc061647..9f586bf4c1 100644
--- a/yarn/src/main/scala/org/apache/spark/deploy/yarn/ApplicationMaster.scala
+++ b/yarn/src/main/scala/org/apache/spark/deploy/yarn/ApplicationMaster.scala
@@ -129,8 +129,9 @@ private[spark] class ApplicationMaster(
// other spark processes running on the same box
System.setProperty("spark.ui.port", "0")
- // Set the master property to match the requested mode.
- System.setProperty("spark.master", "yarn-cluster")
+ // Set the master and deploy mode property to match the requested mode.
+ System.setProperty("spark.master", "yarn")
+ System.setProperty("spark.submit.deployMode", "cluster")
// Propagate the application ID so that YarnClusterSchedulerBackend can pick it up.
System.setProperty("spark.yarn.app.id", appAttemptId.getApplicationId().toString())